
#ifndef FCITX5QT6WIDGETSADDONS_EXPORT_H
#define FCITX5QT6WIDGETSADDONS_EXPORT_H

#ifdef FCITX5QT6WIDGETSADDONS_STATIC_DEFINE
#  define FCITX5QT6WIDGETSADDONS_EXPORT
#  define FCITX5QT6WIDGETSADDONS_NO_EXPORT
#else
#  ifndef FCITX5QT6WIDGETSADDONS_EXPORT
#    ifdef Fcitx5Qt6WidgetsAddons_EXPORTS
        /* We are building this library */
#      define FCITX5QT6WIDGETSADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define FCITX5QT6WIDGETSADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef FCITX5QT6WIDGETSADDONS_NO_EXPORT
#    define FCITX5QT6WIDGETSADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef FCITX5QT6WIDGETSADDONS_DEPRECATED
#  define FCITX5QT6WIDGETSADDONS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef FCITX5QT6WIDGETSADDONS_DEPRECATED_EXPORT
#  define FCITX5QT6WIDGETSADDONS_DEPRECATED_EXPORT FCITX5QT6WIDGETSADDONS_EXPORT FCITX5QT6WIDGETSADDONS_DEPRECATED
#endif

#ifndef FCITX5QT6WIDGETSADDONS_DEPRECATED_NO_EXPORT
#  define FCITX5QT6WIDGETSADDONS_DEPRECATED_NO_EXPORT FCITX5QT6WIDGETSADDONS_NO_EXPORT FCITX5QT6WIDGETSADDONS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef FCITX5QT6WIDGETSADDONS_NO_DEPRECATED
#    define FCITX5QT6WIDGETSADDONS_NO_DEPRECATED
#  endif
#endif

#endif /* FCITX5QT6WIDGETSADDONS_EXPORT_H */
