// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef FCITX5QT6DBUSADDONS_VERSION_H
#define FCITX5QT6DBUSADDONS_VERSION_H

#define FCITX5QT6DBUSADDONS_VERSION_STRING "5.1.9"
#define FCITX5QT6DBUSADDONS_VERSION_MAJOR 5
#define FCITX5QT6DBUSADDONS_VERSION_MINOR 1
#define FCITX5QT6DBUSADDONS_VERSION_PATCH 9
#define FCITX5QT6DBUSADDONS_VERSION ((5<<16)|(1<<8)|(9))

#endif
